
Simmate Visualization
---------------------

This module helpd create plots and 3D models for visualizing data and structures. This ment to be an extension of the `pymatgen.ext` module.

NOTE: Currently, this module only creates 3D models for `Structure` objects usings [Blender](https://www.blender.org/), whereas other functionality is still under planning/development.

Until these tools are more mature, we recommend using either [VESTA](https://jp-minerals.org/vesta/en/) or [OVITO](https://www.ovito.org/) to visualize your crystal structures.
